@@ -21,7 +21,7 @@ from paste.proxy import Proxy
 
 __author__ = "Roberto De Almeida <roberto@dealmeida.net>"
 __license__ = "MIT"
-__version__ = (0,1,0)
+__version__ = (0,1,1)
 
 
 def make_filter(app, global_conf, rulesets=None, config=None):
@@ -290,7 +290,7 @@ class RewriteMiddleware(object):
                 if (internal and
                         "nosubreq" in flags or
                         "NS" in flags):
-                    break
+                    continue
 
                 # Check for an inverted match.
                 if pattern.startswith('!'):
@@ -366,7 +366,8 @@ class RewriteMiddleware(object):
                         e = httpexceptions.HTTPGone()
                         return e.wsgi_application(environ, new_start_response)
 
-                    # Replace path_info with the new value, expading back
+                    # Replace path_info with the new value, expanding any
+                    # back references.
                     new_path_info = pattern.sub(repl, path_info)
                     new_path_info = re.sub(r"(?<!\\)\$(\d)",
                             lambda m: path_pattern[int(m.group(1)) - 1],
@@ -414,7 +415,8 @@ class RewriteMiddleware(object):
                     if repl != '-': environ['PATH_INFO'] = new_path_info
 
                     # Re-run the whold process.
-                    if "N" in flags: return self(environ, new_start_response)
+                    if "N" in flags or "next" in flags:
+                        return self(environ, new_start_response)
 
                     # Skip next rules?
                     skip = [flag for flag in flags if
@@ -425,7 +427,8 @@ class RewriteMiddleware(object):
                                 skip[-1]).group(1))
 
                     # Last rule? Break.
-                    if "L" in flags: break
+                    if "L" in flags or "last" in flags:
+                        break
 
                 # Rule fails and is chained. In this case we set the
                 # skip flag, making rules to be skipped until a non-
@@ -484,11 +487,11 @@ class RewriteMiddleware(object):
             # Do the test. In addition to regexp search, we also
             # allow for lexicographical comparisons.
             if pattern.startswith(">"):
-                m = string > m[1:]
+                m = string > pattern[1:]
             elif pattern.startswith("<"):
-                m = string < m[1:]
+                m = string < pattern[1:]
             elif pattern.startswith("="):
-                m = string == m[1:]
+                m = string == pattern[1:]
             elif "NC" in flags:
                 m = re.search(pattern, string, re.IGNORECASE)
             else:
